@@ -226,6 +226,9 @@ gpm_graph_finalize (GObject *object)
 {
 	GpmGraph *graph = (GpmGraph*) object;
 	cairo_font_options_destroy (graph->priv->options);
+	if (graph->priv->events) {
+		g_list_free (graph->priv->events);
+	}
 }
 
 /**
@@ -266,10 +269,14 @@ gpm_graph_set_invert_y (GpmGraph *graph, gboolean inv)
  * Sets the data for the graph. You MUST NOT free the list before the widget.
  **/
 void
-gpm_graph_set_data (GpmGraph *graph, GList *list)
+gpm_graph_set_data (GpmGraph *graph, GpmInfoData *data)
 {
 	g_return_if_fail (graph != NULL);
 	g_return_if_fail (GPM_IS_GRAPH (graph));
+	GList *list = gpm_info_data_get_list (data);
+	if (graph->priv->list) {
+		g_list_free (graph->priv->list);
+	}
 	graph->priv->list = list;
 }
 
@@ -281,10 +288,14 @@ gpm_graph_set_data (GpmGraph *graph, GList *list)
  * Sets the data for the graph. You MUST NOT free the list before the widget.
  **/
 void
-gpm_graph_set_events (GpmGraph *graph, GList *list)
+gpm_graph_set_events (GpmGraph *graph, GpmInfoData *data)
 {
 	g_return_if_fail (graph != NULL);
 	g_return_if_fail (GPM_IS_GRAPH (graph));
+	GList *list = gpm_info_data_get_list (data);
+	if (graph->priv->events) {
+		g_list_free (graph->priv->events);
+	}
 	graph->priv->events = list;
 }
 
@@ -549,9 +560,9 @@ gpm_graph_auto_range (GpmGraph *graph)
 	if (graph->priv->axis_x == GPM_GRAPH_TYPE_PERCENTAGE) {
 		graph->priv->stop_x = 100;
 	} else if (graph->priv->axis_x == GPM_GRAPH_TYPE_TIME) {
-		graph->priv->stop_x = ((biggest_x / (10 * 60)) + 1) * (10 * 60) + smallest_x;
+		graph->priv->stop_x = (((biggest_x - smallest_x) / (10 * 60)) + 1) * (10 * 60) + smallest_x;
 	} else if (graph->priv->axis_x == GPM_GRAPH_TYPE_RATE) {
-		graph->priv->stop_x = ((biggest_x / 10000) + 2) * 10000 + smallest_x;
+		graph->priv->stop_x = (((biggest_x - smallest_x) / 10000) + 2) * 10000 + smallest_x;
 		if (graph->priv->stop_x < 10000) {
 			graph->priv->stop_x = 10000 + smallest_x;
 		}
