@@ -24,7 +24,7 @@
 #  include <config.h>
 #endif
 
-#define USE_EGGTRAYICON		TRUE
+#define USE_EGGTRAYICON		(GTK_MINOR_VERSION < 9)
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -654,11 +654,9 @@ gpm_tray_icon_popup_menu_cb (GtkStatusIcon *status_icon,
  **/
 static void
 gpm_tray_icon_activate_cb (GtkStatusIcon *status_icon,
-			   guint          button,
-			   guint32        activate_time,
 			   GpmTrayIcon   *icon)
 {
-	g_debug ("icon activated (button:%i)", button);
+	g_debug ("icon activated");
 }
 #endif
 
@@ -856,7 +854,7 @@ libnotify_event (GpmTrayIcon    *icon,
 						     "<span size='larger'><b>%s</b></span>",
 						     GPM_NAME);
 
-	gtk_message_dialog_format_content_markup (GTK_MESSAGE_DIALOG (dialog), content);
+	gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog), content);
 
 	g_signal_connect_swapped (dialog,
 				  "response",
